export type FunctionToDebounce = (...args: any[]) => unknown;
export type DebouncedFunction = {
    (...args: any[]): unknown;
    clear(): void;
    flush(): void;
    destroy(): void;
};
export declare enum DebounceMode {
    /**
     * Debounce using a timeout only. The function will not be called until it has not been called for the specified timeout.
     */
    Timeout = "timeout",
    /**
     * Debounce using a timeout and immediate execution. The function will be called immediately and then not again until it has not been called for the specified timeout.
     */
    ImmediateAndTimeout = "immediate-and-timeout",
    /**
     * Debounce using a maximum frequency. The function will be called immediately and then at most once every timeout. Debounced calls will always use the latest arguments.
     * The debounce function will be called even if its been called within the timeout.
     */
    MaximumFrequency = "maximum-frequency"
}
export declare function useDebounce(func: FunctionToDebounce | EventListenerObject, timeoutMs: number, mode?: DebounceMode): DebouncedFunction;
