import type { DirectiveBinding, VNode } from 'vue';
import type { DebounceMode } from '../composables/useDebounce';
export interface NativeEventOptions {
    /**
     * The name of the native event (e.g. `resize`).
     */
    event: string;
    /**
     * The event handler function to attach. This is the same type as the browser
     * API [`addEventListener.listener` parameter](https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener#the_event_listener_callback).
     */
    listener: EventListenerOrEventListenerObject;
    /**
     * Optional. This is the same type as the browser API [`addEventListener.options` parameter](https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener#options).
     */
    options?: boolean | AddEventListenerOptions;
    /**
     * Optionally specify a debounce timeout.
     */
    debounceMs?: number;
    /**
     * Specify the type of desired debounce behavior. Defaults to `Timeout`.
     */
    debounceMode?: DebounceMode;
    /**
     * Optionally disable/remove the event handler.
     */
    disabled?: boolean | null | undefined;
}
export declare const nativeEventDirective: {
    beforeMount: (domEl: HTMLElement, binding: DirectiveBinding<NativeEventOptions>, vnode: VNode<any, HTMLElement>, prevVnode: VNode<any, HTMLElement> | null) => void;
    updated: (domEl: HTMLElement, binding: DirectiveBinding<NativeEventOptions>, vnode: VNode<any, HTMLElement>, prevVnode: VNode<any, HTMLElement> | null) => void;
    beforeUnmount: (domEl: HTMLElement, binding: DirectiveBinding<NativeEventOptions>, vnode: VNode<any, HTMLElement>, prevVnode: VNode<any, HTMLElement> | null) => void;
};
